import { Facet, Extension } from "@codemirror/state";
/**
 * Sets the block marker
 * Block Marker: Text that indicates a block. E.g. `- `.
 *
 * @defaultValue '- '
 */
export const blockMarkerFacet: Facet<string, string>;
/**
 * Issued if there is a change of a block level.
 */
export type BlockLevelChangeEffectSpec = {
    /**
     * Previous level of block.
     */
    fromLevel: number;
    /**
     * New level of block.
     */
    toLevel: number;
    /**
     * Number of the root block line.
     */
    lineNumber: number;
};
/**
 * Block level effect that contains information about a level change.
 */
export const blockLevelChangeEffect: import("@codemirror/state").StateEffectType<BlockLevelChangeEffectSpec>;
export const blockLevelListenerFacet: Facet<(effect: BlockLevelChangeEffectSpec[]) => void, readonly ((effect: BlockLevelChangeEffectSpec[]) => void)[]>;
/**
 * Extension for CodeMirror6 to allow block-based editing.
 *
 * @returns Extension to enable a block editor.
 */
export function blockEditor(_options?: {}): Extension;
export const version = "0.8.0";

//# sourceMappingURL=index.d.ts.map
